#include <Arduino.h>
#if defined(ESP32)
  #include <WiFi.h>
#elif defined(ESP8266)
  #include <ESP8266WiFi.h>
#endif
#include <Firebase_ESP_Client.h>
//Provide the token generation process info.
#include "addons/TokenHelper.h"
//Provide the RTDB payload printing info and other helper functions.
#include "addons/RTDBHelper.h"
// Insert your network credentials
#define WIFI_SSID "Harvard University"
#define WIFI_PASSWORD NULL
// Insert Firebase project API Key
#define API_KEY "AIzaSyA3YVuiZFF7Rmp_ZLmlPFOd2livI2Raw9k"
// Insert RTDB URLefine the RTDB URL */
#define DATABASE_URL "https://esp32-firebase-final-project-default-rtdb.firebaseio.com/" 

// Define Sensor Pins
#define PRESSURE_PIN_1 32
#define PRESSURE_PIN_2 14
#define PRESSURE_PIN_3 33
#define PRESSURE_PIN_4 36
#define PRESSURE_PIN_5 39
#define PRESSURE_PIN_6 34

//Define Firebase Data object
FirebaseData fbdo;
FirebaseAuth auth;
FirebaseConfig config;
unsigned long sendDataPrevMillis = 0;
//int count = 0;
bool signupOK = false;

void setup(){
  Serial.begin(115200);
  
//  connect to the internet
  WiFi.begin(WIFI_SSID, WIFI_PASSWORD);
  Serial.print("Connecting to Wi-Fi");
  while (WiFi.status() != WL_CONNECTED){
    Serial.print(".");
    delay(300);
  }
  Serial.println();
  Serial.print("Connected with IP: ");
  Serial.println(WiFi.localIP());
  Serial.println();
  /* Assign the api key (required) */
  config.api_key = API_KEY;
  /* Assign the RTDB URL (required) */
  config.database_url = DATABASE_URL;
  /* Sign up */
  if (Firebase.signUp(&config, &auth, "", "")){
    Serial.println("ok");
    signupOK = true;
  }
  else{
    Serial.printf("%s\n", config.signer.signupError.message.c_str());
  }
  /* Assign the callback function for the long running token generation task */
  config.token_status_callback = tokenStatusCallback; //see addons/TokenHelper.h
  
  Firebase.begin(&config, &auth);
  Firebase.reconnectWiFi(true);
}
void loop(){
  int pressure6 = analogRead(PRESSURE_PIN_6);
  int pressure5 = analogRead(PRESSURE_PIN_5);
  int pressure4 = analogRead(PRESSURE_PIN_4);
  int pressure3 = analogRead(PRESSURE_PIN_3);
  int pressure2 = analogRead(PRESSURE_PIN_2); //This pressure sensor was connected to an ADC2 and does not have wireless capabilities
  int pressure1 = analogRead(PRESSURE_PIN_1);
  if (Firebase.ready() && signupOK && (millis() - sendDataPrevMillis > 1000 || sendDataPrevMillis == 0)){
    sendDataPrevMillis = millis();
    // Write an Int number on the database path test/int
    String line = String(pressure1) + "," + String(pressure3) + "," + String(pressure4) + "," + String(pressure5) + "," + String(pressure6);
    if (Firebase.RTDB.setString(&fbdo, "p_values", line)){
      Serial.println("PASSED");
      Serial.println("PATH: " + fbdo.dataPath());
      Serial.println("TYPE: " + fbdo.dataType());
      Serial.println("VALUES: " + line);
    }
    else {
      Serial.println("FAILED");
      Serial.println("REASON: " + fbdo.errorReason());
    }
  }
}
